"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.ModalOverlay = exports.ModalCloseButton = exports.ModalFooter = exports.ModalBody = exports.ModalContent = exports.ModalHeader = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactNative = require("react-native");

var _native = _interopRequireDefault(require("styled-components/native"));

var _styledSystem = require("styled-system");

var _Overlay = require("../../../core/Overlay");

var _hooks = require("../../../hooks");

var _customProps = require("../../../utils/customProps");

var _CloseButton = _interopRequireDefault(require("../../composites/CloseButton"));

var _primitives = require("../../primitives");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const StyledModal = (0, _native.default)(_reactNative.Modal)(_styledSystem.color, _styledSystem.space, _styledSystem.layout, _styledSystem.flexbox, _styledSystem.border, _styledSystem.position, _customProps.customPosition, _customProps.customBorder, _customProps.customBackground, _customProps.customOutline, _customProps.customShadow, _customProps.customExtra, _customProps.customLayout);

const ModalContext = /*#__PURE__*/_react.default.createContext({
  visible: false,
  toggleVisible: _bool => {},
  toggleOnClose: _bool => {},
  newProps: {
    _width: '60%',
    size: 'md',
    modalOverlayStyle: {},
    closeOnOverlayClick: true,
    modalCloseButtonStyle: {},
    modalCloseButtonProps: {},
    modalFooterProps: {},
    modalBodyProps: {},
    modalContentProps: {},
    modalHeaderProps: {},
    modalOverlayProps: {}
  }
});

const Modal = ({
  children,
  isOpen,
  onClose,
  initialFocusRef,
  finalFocusRef,
  justifyContent,
  alignItems,
  id,
  motionPreset,
  avoidKeyboard,
  overlayColor,
  overlayVisible,
  ...props
}, ref) => {
  const {
    closeOverlay,
    setOverlay
  } = (0, _Overlay.useOverlay)();

  const [isVisible, setIsVisible] = _react.default.useState(true);

  const closeOverlayInMobile = () => {
    setIsVisible(false);
    onClose(false);
  };

  const newProps = (0, _hooks.useThemeProps)('Modal', props);
  const value = {
    visible: isVisible,
    toggleVisible: setIsVisible,
    toggleOnClose: onClose ? onClose : () => {},
    newProps: newProps
  };

  const modalChildren = /*#__PURE__*/_react.default.createElement(_primitives.Box, _extends({}, newProps.modalProps, {
    justifyContent: justifyContent !== null && justifyContent !== void 0 ? justifyContent : 'center',
    alignItems: alignItems !== null && alignItems !== void 0 ? alignItems : 'center'
  }), props.closeOnOverlayClick === false ? /*#__PURE__*/_react.default.createElement(_primitives.Box, null) : /*#__PURE__*/_react.default.createElement(ModalOverlay, null), children);

  _react.default.useEffect(() => {
    isOpen && _reactNative.Platform.OS === 'web' ? setOverlay( /*#__PURE__*/_react.default.createElement(ModalContext.Provider, {
      value: value
    }, /*#__PURE__*/_react.default.createElement(_primitives.Box, {
      ref: ref,
      nativeID: id,
      h: "100%"
    }, modalChildren)), {
      onClose: onClose,
      closeOnPress: props.closeOnOverlayClick === false ? false : true,
      backgroundColor: overlayColor ? overlayColor : undefined,
      disableOverlay: overlayVisible === false ? true : false
    }) : setOverlay( /*#__PURE__*/_react.default.createElement(_primitives.Box, null), {
      onClose: closeOverlayInMobile,
      closeOnPress: props.closeOnOverlayClick === false ? false : true,
      backgroundColor: overlayColor ? overlayColor : undefined,
      disableOverlay: overlayVisible === false ? true : false
    });
    !isOpen && closeOverlay();
    setIsVisible(isOpen);
  },
  /*eslint-disable */
  [isOpen]);

  return _reactNative.Platform.OS !== 'web' ? /*#__PURE__*/_react.default.createElement(ModalContext.Provider, {
    value: value
  }, /*#__PURE__*/_react.default.createElement(_primitives.View, {
    nativeID: id
  }, /*#__PURE__*/_react.default.createElement(StyledModal, _extends({
    visible: isVisible,
    onRequestClose: () => {
      value.toggleVisible(false);
      value.toggleOnClose(false);
    },
    onShow: () => {
      var _initialFocusRef$curr;

      return initialFocusRef === null || initialFocusRef === void 0 ? void 0 : (_initialFocusRef$curr = initialFocusRef.current) === null || _initialFocusRef$curr === void 0 ? void 0 : _initialFocusRef$curr.focus();
    },
    onDismiss: () => {
      var _finalFocusRef$curren;

      return finalFocusRef === null || finalFocusRef === void 0 ? void 0 : (_finalFocusRef$curren = finalFocusRef.current) === null || _finalFocusRef$curren === void 0 ? void 0 : _finalFocusRef$curren.focus();
    },
    animationType: motionPreset || 'slide',
    transparent: true
  }, props, {
    ref: ref
  }), avoidKeyboard ? /*#__PURE__*/_react.default.createElement(_reactNative.KeyboardAvoidingView, {
    behavior: _reactNative.Platform.OS === 'ios' ? 'padding' : 'height'
  }, modalChildren) : modalChildren))) : null;
};

const ModalHeader = props => {
  const {
    newProps
  } = _react.default.useContext(ModalContext);

  return /*#__PURE__*/_react.default.createElement(_primitives.Box, _extends({}, newProps.modalHeaderProps, props));
};

exports.ModalHeader = ModalHeader;

const ModalContent = props => {
  const {
    newProps
  } = _react.default.useContext(ModalContext);

  return /*#__PURE__*/_react.default.createElement(_primitives.Box, _extends({}, newProps.modalContentProps, {
    width: newProps._width || newProps.size || '75%'
  }, props));
};

exports.ModalContent = ModalContent;

const ModalBody = props => {
  const {
    newProps
  } = _react.default.useContext(ModalContext);

  return /*#__PURE__*/_react.default.createElement(_primitives.Box, _extends({}, newProps.modalBodyProps, props));
};

exports.ModalBody = ModalBody;

const ModalFooter = props => {
  const {
    newProps
  } = _react.default.useContext(ModalContext);

  return /*#__PURE__*/_react.default.createElement(_primitives.Box, _extends({}, newProps.modalFooterProps, props));
};

exports.ModalFooter = ModalFooter;

const ModalCloseButton = props => {
  const {
    toggleVisible,
    toggleOnClose,
    newProps
  } = _react.default.useContext(ModalContext);

  return /*#__PURE__*/_react.default.createElement(_primitives.View, {
    style: newProps.modalCloseButtonStyle
  }, /*#__PURE__*/_react.default.createElement(_CloseButton.default, _extends({}, newProps.modalCloseButtonProps, props, {
    // accessibilityLabel="Close dialog"
    onPress: () => {
      toggleVisible(false);
      toggleOnClose(false);
    }
  })));
};

exports.ModalCloseButton = ModalCloseButton;

const ModalOverlay = ({
  children,
  ...props
}) => {
  const {
    toggleVisible,
    toggleOnClose,
    newProps
  } = _react.default.useContext(ModalContext);

  return /*#__PURE__*/_react.default.createElement(_primitives.Box, _extends({}, props, {
    style: newProps.modalOverlayStyle
  }), /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    style: newProps.modalOverlayStyle,
    accessible: false,
    onPress: newProps.closeOnOverlayClick === false ? () => {} : () => {
      toggleVisible(false);
      toggleOnClose(false);
    }
  }), children);
};

exports.ModalOverlay = ModalOverlay;

var _default = /*#__PURE__*/_react.default.memo( /*#__PURE__*/_react.default.forwardRef(Modal));

exports.default = _default;
//# sourceMappingURL=index.js.map