"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "PinInputField", {
  enumerable: true,
  get: function () {
    return _PinInputField.default;
  }
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _Stack = require("../../primitives/Stack");

var _hooks = require("../../../hooks");

var _FormControl = require("../FormControl");

var _reactNative = require("react-native");

var _Context = require("./Context");

var _theme = require("../../../theme");

var _remove = _interopRequireDefault(require("lodash/remove"));

var _PinInputField = _interopRequireDefault(require("./PinInputField"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const PinInput = ({
  children,
  ...props
}) => {
  let [padding, remProps] = _theme.themeTools.extractInObject(props, ['p', 'px', 'py', 'pt', 'pb', 'pl', 'pr']);

  const {
    manageFocus,
    defaultValue,
    value,
    space,
    onChange,
    ...newProps
  } = (0, _hooks.useThemeProps)('PinInput', remProps);

  const formControlContext = _react.default.useContext(_FormControl.FormControlContext);

  const RefList = [];

  const setRefList = (ref, index) => {
    RefList[index] = ref;
  };

  const [pinInputValue, setPinInputValue] = _react.default.useState(value || defaultValue);

  const handleChange = (newValue, fieldIndex) => {
    let temp = pinInputValue && [...pinInputValue] || [];
    temp[fieldIndex] = newValue;
    setPinInputValue(temp.join(''));
    onChange && onChange(temp.join(''));
    if (newValue === '' && manageFocus && fieldIndex - 1 > -1) RefList[fieldIndex - 1].current.focus();else if (newValue && manageFocus && fieldIndex + 1 < RefList.length) RefList[fieldIndex + 1].current.focus();
    return temp.join('');
  };

  const handleMultiValueChange = (newValue, fieldIndex) => {
    const pinFieldLength = RefList.length;
    const newValueLength = newValue.length;

    if (newValueLength >= pinFieldLength && newValueLength > 2) {
      let splicedValue = newValue ? [...newValue] : [];
      splicedValue.splice(pinFieldLength);
      RefList[pinFieldLength - 1].current.focus();
      setPinInputValue(splicedValue.join(''));
      onChange && onChange(splicedValue.join(''));
    }

    if (_reactNative.Platform.OS !== 'ios') {
      const temp = pinInputValue ? [...pinInputValue] : [];

      if (newValue === '') {
        // Handling Backward focus.
        temp[fieldIndex];
        (0, _remove.default)(temp, (_n, i) => i === fieldIndex);
        if (manageFocus && fieldIndex - 1 > -1) RefList[fieldIndex - 1].current.focus();
      } else {
        temp[fieldIndex] = JSON.stringify(parseInt(newValue, 10) % 10);
        if (manageFocus && fieldIndex + 1 < RefList.length) RefList[fieldIndex + 1].current.focus();
      }

      setPinInputValue(temp.join(''));
      onChange && onChange(temp.join(''));
    }
  };

  const indexSetter = allChildren => {
    let pinInputFiledCounter = -1;
    return _react.default.Children.map(allChildren, child => {
      if (child.type.type.name !== 'PinInputFiled') return child;else {
        pinInputFiledCounter++;
        return /*#__PURE__*/_react.default.cloneElement(child, {
          fieldIndex: pinInputFiledCounter
        }, child.props.children);
      }
    });
  };

  return /*#__PURE__*/_react.default.createElement(_Context.PinInputContext.Provider, {
    value: { ...formControlContext,
      ...newProps,
      setRefList,
      handleChange,
      handleMultiValueChange,
      value: pinInputValue
    }
  }, children && /*#__PURE__*/_react.default.createElement(_Stack.HStack, _extends({
    flexDirection: "row",
    space: space
  }, padding), indexSetter(children)));
};

var _default = /*#__PURE__*/_react.default.memo(PinInput);

exports.default = _default;
//# sourceMappingURL=index.js.map