"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactNative = require("react-native");

var _utils = require("./../../../utils");

var _hooks = require("../../../hooks");

var _Center = require("../../composites/Center");

var _FormControl = require("../../composites/FormControl");

var _Box = _interopRequireDefault(require("../Box"));

var _Icon = _interopRequireDefault(require("../Icon"));

var _CheckboxGroup = require("./CheckboxGroup");

var _useCheckbox = require("./useCheckbox");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const Checkbox = ({
  icon,
  ...props
}, ref) => {
  const formControlContext = _react.default.useContext(_FormControl.FormControlContext);

  const checkboxGroupContext = _react.default.useContext(_CheckboxGroup.CheckboxContext);

  const {
    activeColor,
    borderColor,
    iconColor,
    size,
    ...newProps
  } = (0, _hooks.useThemeProps)('Checkbox', { ...checkboxGroupContext,
    ...formControlContext,
    ...props
  });
  const {
    inputProps
  } = (0, _useCheckbox.useCheckbox)(props, checkboxGroupContext, null);
  const isChecked = inputProps.checked;
  const isDisabled = inputProps.disabled;
  const sizedIcon = icon ? () => /*#__PURE__*/_react.default.cloneElement(icon, {
    size,
    color: icon.props.color ? icon.props.color : iconColor
  }, icon.props.children) : null;
  return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, _extends({
    activeOpacity: 1,
    ref: ref
  }, inputProps), /*#__PURE__*/_react.default.createElement(_utils.Hoverable, null, isHovered => {
    const outlineColor = isHovered && !isDisabled ? activeColor : isChecked ? isDisabled ? borderColor : activeColor : borderColor;
    return /*#__PURE__*/_react.default.createElement(_Box.default, _extends({
      flexDirection: "row",
      alignItems: "center"
    }, newProps, {
      opacity: isDisabled ? 0.4 : 1
    }, _reactNative.Platform.OS === 'web' ? {
      disabled: isDisabled,
      cursor: isDisabled ? 'not-allowed' : 'auto'
    } : {}), /*#__PURE__*/_react.default.createElement(_Center.Center, {
      backgroundColor: isChecked ? isDisabled ? borderColor : activeColor : 'transparent',
      borderColor: outlineColor,
      borderWidth: 1,
      borderRadius: 4,
      p: 1
    }, icon && sizedIcon && isChecked ? sizedIcon() : /*#__PURE__*/_react.default.createElement(_Icon.default, {
      name: "check-bold",
      type: "MaterialCommunityIcons",
      size: size,
      color: iconColor,
      opacity: isChecked ? 1 : 0
    })), props.children);
  }));
};

var _default = /*#__PURE__*/_react.default.memo( /*#__PURE__*/_react.default.forwardRef(Checkbox));

exports.default = _default;
//# sourceMappingURL=Checkbox.js.map