"use strict";

var _react = _interopRequireDefault(require("react"));

var _reactNative = require("@testing-library/react-native");

var _nativeBase = require("native-base");

var _ = require("..");

var _2 = require("../..");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function CheckBoxGroup() {
  const [groupValue, setGroupValue] = _react.default.useState(['Item 1 ', 'Item 3 ']);

  return /*#__PURE__*/_react.default.createElement(_.CheckboxGroup, {
    colorScheme: "green",
    defaultValue: groupValue,
    onChange: values => {
      setGroupValue(values || []);
    }
  }, /*#__PURE__*/_react.default.createElement(_.Checkbox, {
    value: "Item 1 "
  }, /*#__PURE__*/_react.default.createElement(_2.Text, {
    mx: 2
  }, "Item 1")), /*#__PURE__*/_react.default.createElement(_.Checkbox, {
    value: "Item 2 "
  }, /*#__PURE__*/_react.default.createElement(_2.Text, {
    mx: 2
  }, "Item 2")), /*#__PURE__*/_react.default.createElement(_.Checkbox, {
    value: "Item 3 "
  }, /*#__PURE__*/_react.default.createElement(_2.Text, {
    mx: 2
  }, "Item 3")), /*#__PURE__*/_react.default.createElement(_.Checkbox, {
    colorScheme: "orange",
    value: "Indeterminate Item "
  }, /*#__PURE__*/_react.default.createElement(_2.Text, {
    mx: 2
  }, "Indeterminate Item")));
}

function CheckBox(group) {
  const [groupValues, setGroupValues] = _react.default.useState([]);

  return group ? /*#__PURE__*/_react.default.createElement(_.CheckboxGroup, {
    onChange: setGroupValues,
    value: groupValues
  }, /*#__PURE__*/_react.default.createElement(_.Checkbox, {
    value: "one"
  }, /*#__PURE__*/_react.default.createElement(_2.Text, null, "One")), /*#__PURE__*/_react.default.createElement(_.Checkbox, {
    value: "two",
    isIndeterminate: true,
    onChange: () => setGroupValues([...groupValues, 'two'])
  }, /*#__PURE__*/_react.default.createElement(_2.Text, null, "Two"))) : /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_.Checkbox, {
    value: "one",
    onChange: () => {
      setGroupValues([...groupValues, 'one']);
    }
  }, /*#__PURE__*/_react.default.createElement(_2.Text, null, "One")), /*#__PURE__*/_react.default.createElement(_.Checkbox, {
    value: "two",
    isIndeterminate: true,
    onChange: () => setGroupValues([...groupValues, 'two'])
  }, /*#__PURE__*/_react.default.createElement(_2.Text, null, "Two")));
}

describe('CheckBoxGroup', () => {
  it('handles defaults and onChange on checkBoxGroup', () => {
    let {
      getAllByRole
    } = (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_nativeBase.NativeBaseProvider, null, /*#__PURE__*/_react.default.createElement(CheckBoxGroup, null)));
    let checkbox = getAllByRole('checkbox');
    expect(checkbox.length).toBe(4);
    expect(checkbox[0].props.accessibilityState.checked).toBe(true);
    expect(checkbox[1].props.accessibilityState.checked).toBe(false);
    expect(checkbox[2].props.accessibilityState.checked).toBe(true);
    expect(checkbox[3].props.accessibilityState.checked).toBe(false);

    _reactNative.fireEvent.press(checkbox[1]);

    expect(checkbox[1].props.accessibilityState.checked).toBe(true);
  });
  it('can be disabled on checkBox', () => {
    let {
      getAllByRole
    } = (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_nativeBase.NativeBaseProvider, null, /*#__PURE__*/_react.default.createElement(_.Checkbox, {
      value: "Item 1 "
    }, /*#__PURE__*/_react.default.createElement(_2.Text, {
      mx: 2
    }, "Item 1")), /*#__PURE__*/_react.default.createElement(_.Checkbox, {
      value: "Item 2 ",
      isDisabled: true
    }, /*#__PURE__*/_react.default.createElement(_2.Text, {
      mx: 2
    }, "Item 2")), /*#__PURE__*/_react.default.createElement(_.Checkbox, {
      value: "Item 3 "
    }, /*#__PURE__*/_react.default.createElement(_2.Text, {
      mx: 2
    }, "Item 3")), /*#__PURE__*/_react.default.createElement(_.Checkbox, {
      colorScheme: "orange",
      value: "Indeterminate Item "
    }, /*#__PURE__*/_react.default.createElement(_2.Text, {
      mx: 2
    }, "Indeterminate Item"))));
    let checkbox = getAllByRole('checkbox');
    expect(checkbox.length).toBe(4);
    expect(checkbox[1].props.accessibilityState.disabled).toBe(true);
  });
  it('is checked on checkBox', () => {
    let {
      getAllByRole
    } = (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_nativeBase.NativeBaseProvider, null, /*#__PURE__*/_react.default.createElement(_.Checkbox, {
      value: "Item 1 ",
      isChecked: true
    }, /*#__PURE__*/_react.default.createElement(_2.Text, {
      mx: 2
    }, "Item 1")), /*#__PURE__*/_react.default.createElement(_.Checkbox, {
      value: "Item 2 ",
      isDisabled: true
    }, /*#__PURE__*/_react.default.createElement(_2.Text, {
      mx: 2
    }, "Item 2")), /*#__PURE__*/_react.default.createElement(_.Checkbox, {
      value: "Item 3 "
    }, /*#__PURE__*/_react.default.createElement(_2.Text, {
      mx: 2
    }, "Item 3")), /*#__PURE__*/_react.default.createElement(_.Checkbox, {
      colorScheme: "orange",
      value: "Indeterminate Item "
    }, /*#__PURE__*/_react.default.createElement(_2.Text, {
      mx: 2
    }, "Indeterminate Item"))));
    let checkbox = getAllByRole('checkbox');
    expect(checkbox.length).toBe(4);
    expect(checkbox[0].props.accessibilityState.checked).toBe(true);
  });
  it('inDeterminant on checkBoxGroup', () => {
    let {
      getAllByRole
    } = (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_nativeBase.NativeBaseProvider, null, /*#__PURE__*/_react.default.createElement(CheckBox, {
      group: true
    })));
    let checkbox = getAllByRole('checkbox');
    expect(checkbox.length).toBe(2);

    _reactNative.fireEvent.press(checkbox[1]);

    expect(checkbox[1].props.accessibilityState.checked).toBe(false);
  });
  it('inDeterminant on checkBox', () => {
    let {
      getAllByRole
    } = (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_nativeBase.NativeBaseProvider, null, /*#__PURE__*/_react.default.createElement(CheckBox, {
      group: false
    })));
    let checkbox = getAllByRole('checkbox');
    expect(checkbox.length).toBe(2);

    _reactNative.fireEvent.press(checkbox[1]);

    expect(checkbox[1].props.accessibilityState.checked).toBe(false);
  });
  it('onChange on checkBox', () => {
    let {
      getAllByRole
    } = (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_nativeBase.NativeBaseProvider, null, /*#__PURE__*/_react.default.createElement(CheckBox, null)));
    let checkbox = getAllByRole('checkbox');
    expect(checkbox.length).toBe(2);

    _reactNative.fireEvent.press(checkbox[0]);

    expect(checkbox[0].props.accessibilityState.checked).toBe(true);
  });
});
//# sourceMappingURL=checkbox.test.js.map