"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useCheckbox = useCheckbox;

var _react = _interopRequireDefault(require("react"));

var _hooks = require("../../../hooks");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function useCheckbox(props, state, _ref) {
  let {
    isChecked: isCheckedProp,
    value,
    defaultIsChecked,
    onChange: onChangeProp,
    isIndeterminate,
    isDisabled,
    children,
    accessibilityLabel,
    accessibilityHint
  } = props;
  let {
    value: checkboxGroupValue,
    onChange
  } = state;
  let hasChildren = children != null;
  let hasAccessibilityLabel = accessibilityLabel != null;

  if (!hasChildren && !hasAccessibilityLabel) {
    console.warn('If you do not provide children, you must specify an accessibilityLabel for accessibility');
  }

  const isControlledByGroup = checkboxGroupValue !== undefined;
  const isControlledByProp = isCheckedProp !== undefined;
  let derivedIsChecked;

  if (isControlledByGroup) {
    // @ts-ignore - Already checking for undefined in isControlledByGroup
    derivedIsChecked = checkboxGroupValue.includes(value);
  }

  if (isControlledByProp) {
    derivedIsChecked = isCheckedProp;
  }

  const [checkedState, setCheckedState] = _react.default.useState(defaultIsChecked || false);

  const [isControlled, isChecked] = (0, _hooks.useControllableProp)(derivedIsChecked, checkedState);

  const pressHandler = () => {
    let nextIsChecked = !isChecked;

    if (!isControlled) {
      setCheckedState(nextIsChecked);
    }

    if (!isIndeterminate) {
      onChange && onChange(value, nextIsChecked);
      onChangeProp && onChangeProp(value, nextIsChecked);
    }
  };

  return {
    inputProps: {
      checked: isChecked,
      onPress: pressHandler,
      disabled: isDisabled,
      accessibilityLabel,
      accessibilityRole: 'checkbox',
      accessible: true,
      accessibilityHint,
      accessibilityState: {
        disabled: isDisabled,
        checked: isChecked
      }
    }
  };
}
//# sourceMappingURL=useCheckbox.js.map