"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = Hoverable;

var _react = _interopRequireWildcard(require("react"));

var _state = require("./state");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

// Source: https://gist.github.com/necolas/1c494e44e23eb7f8c5864a2fac66299a
function Hoverable({
  onHoverIn,
  onHoverOut,
  children
}) {
  const [isHovered, setHovered] = _react.default.useState(false);

  const [showHover, setShowHover] = _react.default.useState(true);

  const handleMouseEnter = (0, _react.useCallback)(() => {
    if ((0, _state.isHoverEnabled)() && !isHovered) {
      if (onHoverIn) onHoverIn();
      setHovered(true);
    }
  }, [isHovered, onHoverIn]);
  const handleMouseLeave = (0, _react.useCallback)(() => {
    if (isHovered) {
      if (onHoverOut) onHoverOut();
      setHovered(false);
    }
  }, [isHovered, onHoverOut]);
  const handleGrant = (0, _react.useCallback)(() => {
    setShowHover(false);
  }, []);
  const handleRelease = (0, _react.useCallback)(() => {
    setShowHover(true);
  }, []);
  const child = typeof children === 'function' ? children(showHover && isHovered) : children;
  return /*#__PURE__*/_react.default.cloneElement(_react.default.Children.only(child), {
    onMouseEnter: handleMouseEnter,
    onMouseLeave: handleMouseLeave,
    // prevent hover showing while responder
    onResponderGrant: handleGrant,
    onResponderRelease: handleRelease,
    // if child is Touchable
    onPressIn: handleGrant,
    onPressOut: handleRelease
  });
}
//# sourceMappingURL=index.js.map