import React from 'react';
import View from '../../primitives/View';
import { useThemeProps } from '../../../hooks';
import { usePopover } from '../../../core';
export const Menu = /*#__PURE__*/React.memo(({
  trigger,
  closeOnSelect = true,
  children,
  onOpen,
  onClose,
  ...props
}) => {
  let triggerRef = React.useRef();
  const newProps = useThemeProps('Menu', props);
  let [isOpen, toggle] = React.useState(false);
  const {
    setPopover,
    closePopover
  } = usePopover();

  const closeMenu = () => {
    closePopover();
    toggle(false);
    onClose && onClose();
  };

  const openMenu = () => {
    setPopover( /*#__PURE__*/React.createElement(View, newProps, children), {
      triggerRef,
      animationDuration: 200,
      onClose: closeMenu,
      parentComponentConfig: {
        open: isOpen,
        closeMenu,
        closeOnSelect
      }
    });
    toggle(true);
    onOpen && onOpen();
  };

  return trigger({
    onPress: openMenu,
    ref: triggerRef
  }, {
    open: isOpen
  });
});
//# sourceMappingURL=Menu.js.map