function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { KeyboardAvoidingView, Modal as RNModal, Platform, TouchableOpacity } from 'react-native';
import styled from 'styled-components/native';
import { border, color, flexbox, layout, position, space } from 'styled-system';
import { useOverlay } from '../../../core/Overlay';
import { useThemeProps } from '../../../hooks';
import { customBackground, customBorder, customExtra, customLayout, customOutline, customPosition, customShadow } from '../../../utils/customProps';
import { default as CloseButton } from '../../composites/CloseButton';
import { Box, View } from '../../primitives';
const StyledModal = styled(RNModal)(color, space, layout, flexbox, border, position, customPosition, customBorder, customBackground, customOutline, customShadow, customExtra, customLayout);
const ModalContext = /*#__PURE__*/React.createContext({
  visible: false,
  toggleVisible: _bool => {},
  toggleOnClose: _bool => {},
  newProps: {
    _width: '60%',
    size: 'md',
    modalOverlayStyle: {},
    closeOnOverlayClick: true,
    modalCloseButtonStyle: {},
    modalCloseButtonProps: {},
    modalFooterProps: {},
    modalBodyProps: {},
    modalContentProps: {},
    modalHeaderProps: {},
    modalOverlayProps: {}
  }
});

const Modal = ({
  children,
  isOpen,
  onClose,
  initialFocusRef,
  finalFocusRef,
  justifyContent,
  alignItems,
  id,
  motionPreset,
  avoidKeyboard,
  overlayColor,
  overlayVisible,
  ...props
}, ref) => {
  const {
    closeOverlay,
    setOverlay
  } = useOverlay();
  const [isVisible, setIsVisible] = React.useState(true);

  const closeOverlayInMobile = () => {
    setIsVisible(false);
    onClose(false);
  };

  const newProps = useThemeProps('Modal', props);
  const value = {
    visible: isVisible,
    toggleVisible: setIsVisible,
    toggleOnClose: onClose ? onClose : () => {},
    newProps: newProps
  };
  const modalChildren = /*#__PURE__*/React.createElement(Box, _extends({}, newProps.modalProps, {
    justifyContent: justifyContent !== null && justifyContent !== void 0 ? justifyContent : 'center',
    alignItems: alignItems !== null && alignItems !== void 0 ? alignItems : 'center'
  }), props.closeOnOverlayClick === false ? /*#__PURE__*/React.createElement(Box, null) : /*#__PURE__*/React.createElement(ModalOverlay, null), children);
  React.useEffect(() => {
    isOpen && Platform.OS === 'web' ? setOverlay( /*#__PURE__*/React.createElement(ModalContext.Provider, {
      value: value
    }, /*#__PURE__*/React.createElement(Box, {
      ref: ref,
      nativeID: id,
      h: "100%"
    }, modalChildren)), {
      onClose: onClose,
      closeOnPress: props.closeOnOverlayClick === false ? false : true,
      backgroundColor: overlayColor ? overlayColor : undefined,
      disableOverlay: overlayVisible === false ? true : false
    }) : setOverlay( /*#__PURE__*/React.createElement(Box, null), {
      onClose: closeOverlayInMobile,
      closeOnPress: props.closeOnOverlayClick === false ? false : true,
      backgroundColor: overlayColor ? overlayColor : undefined,
      disableOverlay: overlayVisible === false ? true : false
    });
    !isOpen && closeOverlay();
    setIsVisible(isOpen);
  },
  /*eslint-disable */
  [isOpen]);
  return Platform.OS !== 'web' ? /*#__PURE__*/React.createElement(ModalContext.Provider, {
    value: value
  }, /*#__PURE__*/React.createElement(View, {
    nativeID: id
  }, /*#__PURE__*/React.createElement(StyledModal, _extends({
    visible: isVisible,
    onRequestClose: () => {
      value.toggleVisible(false);
      value.toggleOnClose(false);
    },
    onShow: () => {
      var _initialFocusRef$curr;

      return initialFocusRef === null || initialFocusRef === void 0 ? void 0 : (_initialFocusRef$curr = initialFocusRef.current) === null || _initialFocusRef$curr === void 0 ? void 0 : _initialFocusRef$curr.focus();
    },
    onDismiss: () => {
      var _finalFocusRef$curren;

      return finalFocusRef === null || finalFocusRef === void 0 ? void 0 : (_finalFocusRef$curren = finalFocusRef.current) === null || _finalFocusRef$curren === void 0 ? void 0 : _finalFocusRef$curren.focus();
    },
    animationType: motionPreset || 'slide',
    transparent: true
  }, props, {
    ref: ref
  }), avoidKeyboard ? /*#__PURE__*/React.createElement(KeyboardAvoidingView, {
    behavior: Platform.OS === 'ios' ? 'padding' : 'height'
  }, modalChildren) : modalChildren))) : null;
};

export const ModalHeader = props => {
  const {
    newProps
  } = React.useContext(ModalContext);
  return /*#__PURE__*/React.createElement(Box, _extends({}, newProps.modalHeaderProps, props));
};
export const ModalContent = props => {
  const {
    newProps
  } = React.useContext(ModalContext);
  return /*#__PURE__*/React.createElement(Box, _extends({}, newProps.modalContentProps, {
    width: newProps._width || newProps.size || '75%'
  }, props));
};
export const ModalBody = props => {
  const {
    newProps
  } = React.useContext(ModalContext);
  return /*#__PURE__*/React.createElement(Box, _extends({}, newProps.modalBodyProps, props));
};
export const ModalFooter = props => {
  const {
    newProps
  } = React.useContext(ModalContext);
  return /*#__PURE__*/React.createElement(Box, _extends({}, newProps.modalFooterProps, props));
};
export const ModalCloseButton = props => {
  const {
    toggleVisible,
    toggleOnClose,
    newProps
  } = React.useContext(ModalContext);
  return /*#__PURE__*/React.createElement(View, {
    style: newProps.modalCloseButtonStyle
  }, /*#__PURE__*/React.createElement(CloseButton, _extends({}, newProps.modalCloseButtonProps, props, {
    // accessibilityLabel="Close dialog"
    onPress: () => {
      toggleVisible(false);
      toggleOnClose(false);
    }
  })));
};
export const ModalOverlay = ({
  children,
  ...props
}) => {
  const {
    toggleVisible,
    toggleOnClose,
    newProps
  } = React.useContext(ModalContext);
  return /*#__PURE__*/React.createElement(Box, _extends({}, props, {
    style: newProps.modalOverlayStyle
  }), /*#__PURE__*/React.createElement(TouchableOpacity, {
    style: newProps.modalOverlayStyle,
    accessible: false,
    onPress: newProps.closeOnOverlayClick === false ? () => {} : () => {
      toggleVisible(false);
      toggleOnClose(false);
    }
  }), children);
};
export default /*#__PURE__*/React.memo( /*#__PURE__*/React.forwardRef(Modal));
//# sourceMappingURL=index.js.map