import React from 'react';
import { useThemeProps } from '../../../hooks';
import { FormControlContext } from '../FormControl';
import { NumberInputContext } from './Context';

const NumberInput = ({
  children,
  ...props
}) => {
  const {
    defaultValue,
    keepWithinRange,
    value,
    min,
    max,
    onChange,
    ...newProps
  } = useThemeProps('NumberInput', props);
  const formControlContext = React.useContext(FormControlContext);
  const [numberInputValue, setNumberInputValue] = React.useState(parseInt(value || defaultValue, 10));

  const handleChange = newValue => {
    const temp = newValue;
    setNumberInputValue(temp);

    if (keepWithinRange) {
      if (newValue < min) setNumberInputValue(min);else if (newValue > max) setNumberInputValue(max);
    } //NOTE: only calling onChange on stepper click or blur event of input.


    onChange && onChange(temp);
  };

  const handleChangeWithoutCheck = newValue => {
    const temp = newValue;
    setNumberInputValue(temp);
  };

  let numberInputStepper = null;

  const separatingNumberInputStepper = allChildren => {
    return React.Children.map(allChildren, child => {
      if (child.type.type.name === 'NumberInputStepper') {
        numberInputStepper = child;
        return null;
      } else {
        return child;
      }
    });
  };

  const updatedChildren = separatingNumberInputStepper(children);
  return /*#__PURE__*/React.createElement(NumberInputContext.Provider, {
    value: { ...formControlContext,
      ...newProps,
      min,
      max,
      handleChange,
      handleChangeWithoutCheck,
      numberInputValue,
      numberInputStepper
    }
  }, updatedChildren);
};

export default /*#__PURE__*/React.memo(NumberInput);
//# sourceMappingURL=NumberInput.js.map