function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import styled from 'styled-components/native';
import { border, color, flexbox, layout, position, space } from 'styled-system';
import { useThemeProps } from '../../../hooks';
import { customBackground, customBorder, customExtra, customLayout, customOutline, customPosition, customShadow } from '../../../utils/customProps';
import { default as Box } from '../../primitives/Box';
import View from '../../primitives/View';
import CloseButton from '../CloseButton';
import Tooltip from './Tooltip';
const StyledPopover = styled(Tooltip)(color, space, layout, flexbox, border, position, customPosition, customBorder, customBackground, customOutline, customShadow, customExtra, customLayout);
const PopoverContext = /*#__PURE__*/React.createContext({
  PopoverTrigger: null,
  setPopoverTrigger: _child => {},
  PopoverRef: null,
  backgroundColor: '',
  borderColor: '',
  borderWidth: null,
  initialFocusRef: null,
  finalFocusRef: null,
  isVisible: false,
  setIsVisible: _bool => {},
  onOpen: () => {},
  onClose: () => {},
  closeOnBlur: true,
  newProps: {
    popoverCloseButtonProps: {},
    popoverFooterProps: {},
    popoverBodyProps: {},
    popoverContentProps: {},
    popoverHeaderProps: {}
  }
});

const Popover = ({
  children,
  initialFocusRef,
  finalFocusRef,
  onOpen,
  onClose,
  closeOnBlur,
  id,
  backgroundColor,
  bg,
  borderWidth,
  borderColor,
  ...props
}) => {
  const [trigger, setTrigger] = React.useState();
  const [isVisible, setIsVisible] = React.useState(false);
  const popOverRef = React.useRef(null);
  const newProps = useThemeProps('Popover', props);
  const value = {
    PopoverTrigger: trigger,
    setPopoverTrigger: setTrigger,
    PopoverRef: popOverRef,
    initialFocusRef: initialFocusRef,
    finalFocusRef: finalFocusRef,
    isVisible: isVisible,
    setIsVisible: setIsVisible,
    onOpen: onOpen,
    onClose: onClose,
    newProps: newProps,
    closeOnBlur: closeOnBlur,
    backgroundColor: bg || backgroundColor || { ...newProps.popoverProps
    }.backgroundColor,
    borderColor: borderColor || { ...newProps.popoverProps
    }.borderColor,
    borderWidth: borderWidth || { ...newProps.popoverProps
    }.borderWidth
  };
  return /*#__PURE__*/React.createElement(PopoverContext.Provider, {
    value: value
  }, /*#__PURE__*/React.createElement(View, {
    nativeID: id
  }, children));
};

export const PopoverTrigger = ({
  children
}) => {
  const {
    setPopoverTrigger
  } = React.useContext(PopoverContext);
  React.useEffect(() => {
    setPopoverTrigger(React.Children.map(children, child => {
      return /*#__PURE__*/React.cloneElement(child, {
        isDisabled: true,
        disabled: true
      }, child.props.children);
    }));
  }, [setPopoverTrigger, children]);
  return null;
};
export const PopoverHeader = props => {
  const {
    newProps: {
      popoverHeaderProps
    }
  } = React.useContext(PopoverContext);
  return /*#__PURE__*/React.createElement(Box, _extends({}, popoverHeaderProps, props));
};
export const PopoverContent = ({
  children,
  ...props
}) => {
  const {
    PopoverRef,
    PopoverTrigger,
    onOpen,
    initialFocusRef,
    onClose,
    finalFocusRef,
    closeOnBlur,
    newProps,
    backgroundColor,
    borderColor,
    borderWidth
  } = React.useContext(PopoverContext);
  return /*#__PURE__*/React.createElement(StyledPopover, _extends({}, newProps.popoverContentProps, {
    width: newProps._width || newProps.size || '45%',
    backgroundColor: backgroundColor,
    borderColor: borderColor,
    borderWidth: borderWidth,
    ref: PopoverRef,
    onOpen: () => {
      onOpen && onOpen();
      initialFocusRef === null || initialFocusRef === void 0 ? void 0 : initialFocusRef.current.focus();
    },
    onClose: () => {
      onClose && onClose();
      finalFocusRef === null || finalFocusRef === void 0 ? void 0 : finalFocusRef.current.focus();
    },
    closeOnBlur: closeOnBlur !== null && closeOnBlur !== void 0 ? closeOnBlur : true,
    popover: /*#__PURE__*/React.createElement(Box, {
      width: "100%"
    }, /*#__PURE__*/React.createElement(Box, null, children))
  }, props), PopoverTrigger);
};
export const PopoverBody = props => {
  const {
    newProps: {
      popoverBodyProps
    },
    borderColor,
    borderWidth
  } = React.useContext(PopoverContext);
  return /*#__PURE__*/React.createElement(Box, _extends({}, popoverBodyProps, {
    borderTopColor: borderColor,
    borderTopWidth: borderWidth
  }, props));
};
export const PopoverFooter = props => {
  const {
    newProps: {
      popoverFooterProps
    },
    borderColor,
    borderWidth
  } = React.useContext(PopoverContext);
  return /*#__PURE__*/React.createElement(Box, _extends({}, popoverFooterProps, {
    borderTopColor: borderColor,
    borderTopWidth: borderWidth
  }, props));
};
export const PopoverCloseButton = props => {
  const {
    PopoverRef,
    newProps: {
      popoverCloseButtonProps
    }
  } = React.useContext(PopoverContext);
  return /*#__PURE__*/React.createElement(View, {
    position: "absolute",
    right: 0,
    top: 0,
    zIndex: 1
  }, /*#__PURE__*/React.createElement(CloseButton, _extends({}, popoverCloseButtonProps, props, {
    onPress: () => PopoverRef === null || PopoverRef === void 0 ? void 0 : PopoverRef.current.toggleTooltip()
  })));
};
export default /*#__PURE__*/React.memo(Popover);
//# sourceMappingURL=index.js.map