function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { Animated, Platform } from 'react-native';
import { useThemeProps } from '../../../hooks';
import { canUseDom } from '../../../utils';
import Box from '../../primitives/Box';

const Bones = allProps => {
  const isDomUsable = canUseDom();
  const {
    circle,
    children,
    ...props
  } = allProps;
  const newProps = useThemeProps('Skeleton', props);
  const {
    style,
    skeletonColor,
    baseColor
  } = newProps;
  const blinkAnim = React.useRef(new Animated.Value(0)).current;
  React.useEffect(() => {
    if (isDomUsable) {
      const blink = Animated.sequence([Animated.timing(blinkAnim, {
        toValue: 1,
        duration: 1000,
        useNativeDriver: Platform.OS !== 'web'
      }), Animated.timing(blinkAnim, {
        toValue: 0,
        duration: 1000,
        useNativeDriver: Platform.OS !== 'web'
      })]);
      Animated.loop(blink).start();
    }
  }, [blinkAnim, isDomUsable]);
  const skeletonStyle = {
    skeleton: {
      position: 'absolute',
      top: 0,
      bottom: 0,
      left: 0,
      right: 0,
      borderRadius: circle ? 999 : 3,
      backgroundColor: skeletonColor,
      opacity: blinkAnim // Bind opacity to animated value

    },
    base: {
      borderRadius: circle ? 999 : 3,
      backgroundColor: baseColor
    }
  };

  const AnimationViewSetter = () => {
    if (children) {
      if (children.length) {
        return [/*#__PURE__*/React.createElement(Animated.View, {
          style: skeletonStyle.skeleton
        }), ...children];
      }

      return [/*#__PURE__*/React.createElement(Animated.View, {
        style: skeletonStyle.skeleton
      }), children];
    }

    return /*#__PURE__*/React.createElement(Animated.View, {
      style: skeletonStyle.skeleton
    });
  };

  return /*#__PURE__*/React.createElement(Box, _extends({
    style: [style, skeletonStyle.base]
  }, props), AnimationViewSetter());
};

export default /*#__PURE__*/React.memo(Bones);
//# sourceMappingURL=Bones.js.map