function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { TouchableOpacity, Platform } from 'react-native';
import { Hoverable } from './../../../utils';
import { useThemeProps } from '../../../hooks';
import { Center } from '../../composites/Center';
import { FormControlContext } from '../../composites/FormControl';
import Box from '../Box';
import Icon from '../Icon';
import { CheckboxContext } from './CheckboxGroup';
import { useCheckbox } from './useCheckbox';

const Checkbox = ({
  icon,
  ...props
}, ref) => {
  const formControlContext = React.useContext(FormControlContext);
  const checkboxGroupContext = React.useContext(CheckboxContext);
  const {
    activeColor,
    borderColor,
    iconColor,
    size,
    ...newProps
  } = useThemeProps('Checkbox', { ...checkboxGroupContext,
    ...formControlContext,
    ...props
  });
  const {
    inputProps
  } = useCheckbox(props, checkboxGroupContext, null);
  const isChecked = inputProps.checked;
  const isDisabled = inputProps.disabled;
  const sizedIcon = icon ? () => /*#__PURE__*/React.cloneElement(icon, {
    size,
    color: icon.props.color ? icon.props.color : iconColor
  }, icon.props.children) : null;
  return /*#__PURE__*/React.createElement(TouchableOpacity, _extends({
    activeOpacity: 1,
    ref: ref
  }, inputProps), /*#__PURE__*/React.createElement(Hoverable, null, isHovered => {
    const outlineColor = isHovered && !isDisabled ? activeColor : isChecked ? isDisabled ? borderColor : activeColor : borderColor;
    return /*#__PURE__*/React.createElement(Box, _extends({
      flexDirection: "row",
      alignItems: "center"
    }, newProps, {
      opacity: isDisabled ? 0.4 : 1
    }, Platform.OS === 'web' ? {
      disabled: isDisabled,
      cursor: isDisabled ? 'not-allowed' : 'auto'
    } : {}), /*#__PURE__*/React.createElement(Center, {
      backgroundColor: isChecked ? isDisabled ? borderColor : activeColor : 'transparent',
      borderColor: outlineColor,
      borderWidth: 1,
      borderRadius: 4,
      p: 1
    }, icon && sizedIcon && isChecked ? sizedIcon() : /*#__PURE__*/React.createElement(Icon, {
      name: "check-bold",
      type: "MaterialCommunityIcons",
      size: size,
      color: iconColor,
      opacity: isChecked ? 1 : 0
    })), props.children);
  }));
};

export default /*#__PURE__*/React.memo( /*#__PURE__*/React.forwardRef(Checkbox));
//# sourceMappingURL=Checkbox.js.map