import get from 'lodash/get';
import omit from 'lodash/omit';
import { useWindowDimensions, Platform } from 'react-native';
import { useNativeBase } from './../useNativeBase';
import { omitUndefined, extractInObject } from './../../theme/tools/';
import { filterShadowProps } from './../../utils/filterShadowProps';
import { calculateProps } from './utils';

const filterAndCalculateProps = (theme, colorModeProps, componentTheme, propsReceived, windowWidth) => {
  // Extracting out children and style, as they do not contribute in props calculation
  let [ignoredProps, props] = extractInObject(propsReceived, ['children', 'style', 'onPress', 'icon', 'onOpen', 'onClose']);
  let newProps = calculateProps(theme, colorModeProps, componentTheme, props, windowWidth);
  let mergedProps = filterShadowProps(newProps, ignoredProps, Platform.OS);
  return omitUndefined(mergedProps);
};

export function useThemeProps(component, propsReceived) {
  var _useWindowDimensions;

  const {
    theme,
    ...colorModeProps
  } = useNativeBase();
  const componentTheme = get(theme, "components.".concat(component));
  let windowWidth = (_useWindowDimensions = useWindowDimensions()) === null || _useWindowDimensions === void 0 ? void 0 : _useWindowDimensions.width;
  return filterAndCalculateProps(omit(theme, ['components']), colorModeProps, componentTheme, propsReceived, windowWidth);
}
//# sourceMappingURL=useProps.js.map