import { mode } from './../tools';
const baseStyle = {
  borderRadius: 'lg',
  fontWeight: 'semibold',
  display: 'flex',
  flexDirection: 'row',
  justifyContent: 'center',
  alignItems: 'center'
};

function variantGhost(props) {
  const {
    colorScheme: c
  } = props;

  if (c === 'gray') {
    return {
      color: mode("gray.500", "whiteAlpha.900")(props)
    };
  }

  return {
    color: mode("".concat(c, ".500"), "".concat(c, ".200"))(props),
    bg: 'transparent'
  };
}

function variantOutline(props) {
  const {
    colorScheme: c
  } = props;
  const borderColor = mode("gray.200", "whiteAlpha.300")(props);
  return {
    border: '1px solid',
    borderColor: c === 'gray' ? borderColor : mode("".concat(c, ".500"), "".concat(c, ".200"))(props),
    ...variantGhost(props)
  };
}

/** Accessible color overrides for less accessible colors. */
const accessibleColorMap = {
  yellow: {
    bg: 'yellow.400',
    color: 'black'
  },
  cyan: {
    bg: 'cyan.400',
    color: 'black'
  }
};

function variantSolid(props) {
  const {
    colorScheme: c
  } = props;
  if (c === 'gray') return {
    bg: mode("gray.100", "whiteAlpha.200")(props)
  };
  const {
    bg = "".concat(c, ".500"),
    color = 'white'
  } = accessibleColorMap[c] || {};
  return {
    bg: mode(bg, "".concat(c, ".400"))(props),
    color: mode(color, "gray.800")(props)
  };
}

function variantLink(props) {
  const {
    colorScheme: c
  } = props;
  return {
    padding: 0,
    height: 'auto',
    // lineHeight: 'normal',
    color: mode("".concat(c, ".500"), "".concat(c, ".200"))(props),
    textDecorationLine: 'underline'
  };
}

function variantUnstyled() {
  return {
    m: 0,
    p: 0
  };
}

const variants = {
  ghost: variantGhost,
  outline: variantOutline,
  solid: variantSolid,
  link: variantLink,
  unstyled: variantUnstyled
};
const sizes = {
  lg: {
    minH: 12,
    minW: 12,
    fontSize: 'lg',
    px: 6,
    py: 4
  },
  md: {
    minH: 10,
    minW: 10,
    fontSize: 'md',
    px: 5,
    py: 3
  },
  sm: {
    minH: 8,
    minW: 8,
    fontSize: 'sm',
    px: 4,
    py: 2
  },
  xs: {
    minH: 6,
    minW: 6,
    fontSize: 'xs',
    px: 2
  }
};
const defaultProps = {
  variant: 'solid',
  size: 'md',
  colorScheme: 'gray'
};
export default {
  baseStyle,
  variants,
  sizes,
  defaultProps
};
//# sourceMappingURL=button.js.map