// Source: https://gist.github.com/necolas/1c494e44e23eb7f8c5864a2fac66299a
import React, { useCallback } from 'react';
import { isHoverEnabled } from './state';
export default function Hoverable({
  onHoverIn,
  onHoverOut,
  children
}) {
  const [isHovered, setHovered] = React.useState(false);
  const [showHover, setShowHover] = React.useState(true);
  const handleMouseEnter = useCallback(() => {
    if (isHoverEnabled() && !isHovered) {
      if (onHoverIn) onHoverIn();
      setHovered(true);
    }
  }, [isHovered, onHoverIn]);
  const handleMouseLeave = useCallback(() => {
    if (isHovered) {
      if (onHoverOut) onHoverOut();
      setHovered(false);
    }
  }, [isHovered, onHoverOut]);
  const handleGrant = useCallback(() => {
    setShowHover(false);
  }, []);
  const handleRelease = useCallback(() => {
    setShowHover(true);
  }, []);
  const child = typeof children === 'function' ? children(showHover && isHovered) : children;
  return /*#__PURE__*/React.cloneElement(React.Children.only(child), {
    onMouseEnter: handleMouseEnter,
    onMouseLeave: handleMouseLeave,
    // prevent hover showing while responder
    onResponderGrant: handleGrant,
    onResponderRelease: handleRelease,
    // if child is Touchable
    onPressIn: handleGrant,
    onPressOut: handleRelease
  });
}
//# sourceMappingURL=index.js.map